import tiktoken


class GPT4oTokenizer:
    def __init__(
        self,
        model_name: str = "gpt-4o",
        base_model: str = "o200k_base",
        *args,
        **kwargs
    ):  
        self.tokenizer = tiktoken.encoding_for_model(model_name, *args, **kwargs)
    
    def encode(self, text: str, *args, **kwargs):
        """
        Encodes the given text into a list of tokens.

        Args:
            text (str): The input text to be encoded.
            *args: Variable length arguments to be passed to the tokenizer.
            **kwargs: Keyword arguments to be passed to the tokenizer.

        Returns:
            list[int]: The encoded tokens.
        """
        return self.tokenizer.encode(text, *args, **kwargs)

    def decode(self, tokens: list[int], *args, **kwargs):
        """
        Decodes the given list of tokens into text.

        Args:
            tokens (list[int]): The input tokens to be decoded.
            *args: Variable length arguments to be passed to the tokenizer.
            **kwargs: Keyword arguments to be passed to the tokenizer.

        Returns:
            str: The decoded text.
        """
        return self.tokenizer.decode(tokens, *args, **kwargs)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['gpt4o']

package_data = \
{'': ['*']}

install_requires = \
['einops', 'torch', 'zetascale']

setup_kwargs = {
    'name': 'gpt4o',
    'version': '0.0.1',
    'description': 'gpt4o - Pytorch',
    'long_description': "[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)\n\n# GPT4o\nCommunity Open Source Implementation of GPT4o in PyTorch\n\n\n## Install\n\n\n# Architecture\n- TikToken Tokenzier: We know fursure the tokenizer. [Which is here](https://github.com/openai/tiktoken)\n- Model understands Images and Audio Natively. There are 2 approaches, process them natively or use encoders for each. I think here they're using encoders like whisper and vit for simplicity and brevity.\n- Using DALLE3 as the output head to generate images\n- Tokens to denote when to generate an image or audio\n- Whisper output head for the audio outputs\n- \n\n# License\nMIT\n",
    'author': 'Kye Gomez',
    'author_email': 'kye@apac.ai',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/kyegomez/gpt4o',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
